@@ -118,7 +118,7 @@ void KMFIPTWatcher::queryChainsInTable( const TQString& table, KMFIPTDoc* iptdoc
 		emit sigUpdateActive( false );
 	} else {
 		TQDataStream answer( reply_data, IO_ReadOnly );
-		if ( reply_type == TQSTRINGLIST_OBJECT_NAME_STRING ) {
+		if ( reply_type == "TQStringList" ) {
 			TQStringList result;
 			answer >> result;
 			IPTable *tableObj = iptdoc->table( table ); 
@@ -175,7 +175,7 @@ void KMFIPTWatcher::fetchChainPolicy( IPTChain* chain ) {
 		emit sigUpdateActive( false );
 	} else {
 		TQDataStream answer( reply_data, IO_ReadOnly );
-		if ( reply_type == TQSTRING_OBJECT_NAME_STRING ) {
+		if ( reply_type == "TQString" ) {
 			TQString result;
 			answer >> result;
 			kdDebug() << "Found Chain Policy: " << chain->table()->name()  << " " << chain->name()  << " " << result << endl;
@@ -253,7 +253,7 @@ void KMFIPTWatcher::fetchRulesProperties( IPTRule* rule, int index ) {
 		emit sigUpdateActive( false );
 	} else {
 		TQDataStream answer( reply_data, IO_ReadOnly );
-		if ( reply_type == TQSTRINGLIST_OBJECT_NAME_STRING ) {
+		if ( reply_type == "TQStringList" ) {
 			TQStringList result;
 			answer >> result;
 			if ( *result.at( 0 ) == "ERROR" ) {
