@@ -41,7 +41,7 @@ class KMFIPTDoc;
 
 class KMFSysTray : public KSystemTray, public DCOPObject
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 
 public:
