@@ -28,7 +28,7 @@ class Details;
 
 class MainWidget : public MainWidgetDesigner
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 
 public:
