@@ -42,7 +42,7 @@ class KMFIPTDoc;
 class KMFErrorHandler;
 
 class KMFIPTablesCompiler :  public KMFPlugin, public virtual KMFCompilerInterface {
-	Q_OBJECT
+	TQ_OBJECT
   
 public:
 	KMFIPTablesCompiler( TQObject* parent, const char* name );
@@ -75,7 +75,7 @@ private:
 
 
 class KMFIPTablesCompilerFactory : public KLibFactory {
-	Q_OBJECT
+	TQ_OBJECT
   
 public:
 	KMFIPTablesCompilerFactory( TQObject *parent = 0, const char *name = 0 );
@@ -83,7 +83,7 @@ public:
 /* 		delete s_instance; */
 	};
 	virtual TQObject* createObject( TQObject* parent = 0, const char* pname = 0,
-	                               const char* name = TQOBJECT_OBJECT_NAME_STRING,
+	                               const char* name = "TQObject",
 	                               const TQStringList &args = TQStringList() );
 	/*     static TDEInstance* instance(); */
 
