@@ -44,7 +44,7 @@ class IPTChain;
 
 
 class KMFPFCompiler :  public KMFPlugin, public virtual KMFCompilerInterface {
-	Q_OBJECT
+	TQ_OBJECT
   
 public:
 	KMFPFCompiler( TQObject* parent, const char* name );
@@ -114,7 +114,7 @@ private slots:
 
 
 class KMFPFCompilerFactory : public KLibFactory {
-	Q_OBJECT
+	TQ_OBJECT
   
 public:
 	KMFPFCompilerFactory( TQObject *parent = 0, const char *name = 0 );
@@ -122,7 +122,7 @@ public:
 /* 		delete s_instance; */
 	};
 	virtual TQObject* createObject( TQObject* parent = 0, const char* pname = 0,
-	                               const char* name = TQOBJECT_OBJECT_NAME_STRING,
+	                               const char* name = "TQObject",
 	                               const TQStringList &args = TQStringList() );
 	/*     static TDEInstance* instance(); */
 
