@@ -54,7 +54,7 @@ class KMFNetwork;
 */
 
 class KDE_EXPORT KMFNetHost : public KMFTarget {
-	Q_OBJECT
+	TQ_OBJECT
   
 public:
 	KMFNetHost( NetfilterObject *parent, const char* name, const TQString& Hostname, KMFNetwork* net );
