@@ -50,7 +50,7 @@ class KMFNetwork;
 
 //############ KMFNetZone #############
 class KDE_EXPORT KMFNetZone : public NetfilterObject {
-	Q_OBJECT
+	TQ_OBJECT
   
 public:
 	KMFNetZone( NetfilterObject *parent, const char* objectname, const TQString& name );
