@@ -27,7 +27,7 @@ class KMFProtocolCategory;
 	@author Christian Hubinger <chubinger@irrsinnig.org>
 */
 class KMFProtocolLibrary : public TQObject {
-Q_OBJECT
+TQ_OBJECT
   
 /** Static Stuff **/
 public:
