@@ -35,7 +35,7 @@ namespace KMF {
 
 class KMFProtocolUsage : public NetfilterObject {
 	friend class KMFProtocol;
-Q_OBJECT
+TQ_OBJECT
   
 public:
 	
