@@ -35,7 +35,7 @@ class KMFNetwork;
 */
 
 class KMFUndoEngine : public TQObject {
-	Q_OBJECT
+	TQ_OBJECT
   
 	
 	friend class KMFTransaction;
