@@ -216,7 +216,7 @@ void KMFGenericInterface::loadIcons() {
 	icon_name = "services";
 	icon_protocol_page = loader->loadIcon( icon_name, TDEIcon::Desktop );
 
-	icon_name = "nfs_unmount";
+	icon_name = "nfs-unmounted";
 	icon_edit_protocol_page = loader->loadIcon( icon_name, TDEIcon::Desktop );
 
 	icon_name = "pipe";
