@@ -55,7 +55,7 @@ class KMFMyNetworkWidget;
 class NetfilterObject;
 
 class KMFGenericInterface : public KJanusWidget {
-	Q_OBJECT
+	TQ_OBJECT
   
 public:
 
