@@ -52,7 +52,7 @@ class KMFListViewItem;
 class NetfilterObject;
 
 class KMFGenericInterfaceHost : public KMyFirewallGenericInterfaceHostWidget {
-	Q_OBJECT
+	TQ_OBJECT
   
 public:
 	KMFGenericInterfaceHost( TQWidget *parent = 0, const char *name = 0, WFlags f = 0 );
