@@ -37,7 +37,7 @@ class KMFNetwork;
 class NetfilterObject;
 
 class KMFGenericInterfaceIcmp : public KMyFirewallGenericInterfaceIcmp {
-	Q_OBJECT
+	TQ_OBJECT
   
 public:
 	KMFGenericInterfaceIcmp( TQWidget *parent = 0, const char *name = 0, WFlags f = 0 );
