@@ -41,7 +41,7 @@ class KMFGenericDoc;
 class NetfilterObject;
 
 class KMFGenericInterfaceLogging : public KMyFirewallGenericInterfaceLogging {
-	Q_OBJECT
+	TQ_OBJECT
   
 public:
 	KMFGenericInterfaceLogging( TQWidget *parent = 0, const char *name = 0, WFlags f = 0 );
