@@ -61,7 +61,7 @@ class KMFProtocolPropertiesWidget;
 class KMFProtocolListView;
 
 class KMFGenericInterfaceProtocol : public KMyFirewallGenericInterfaceProtocolWidget {
-	Q_OBJECT
+	TQ_OBJECT
   
 public:
 	KMFGenericInterfaceProtocol( TQWidget *parent = 0, const char *name = 0, WFlags f = 0 );
