@@ -58,7 +58,7 @@ class KMFMainWindow;
 class KMFMyNetworkWidget;
 
 class KMFRuleEdit : public KMyFirewallRuleEditor, public KMFRuleEditInterface {
-	Q_OBJECT
+	TQ_OBJECT
   
 
 public:
