@@ -25,7 +25,7 @@ namespace KMF {
 class KMFDoc;
 
 class KDE_EXPORT KMFDocumentInfo : public KMyFirewallDocumentInfo {
-	Q_OBJECT
+	TQ_OBJECT
   
 
 public:
