@@ -45,7 +45,7 @@ class KMFListViewItem;
 class KMFProtocolCategory;
 
 class KMFGenericInterfaceEditProtocol : public KMyFirewallGenericInterfaceEditProtocolWidget {
-	Q_OBJECT
+	TQ_OBJECT
   
 public:
 	KMFGenericInterfaceEditProtocol( TQWidget *parent = 0, const char *name = 0, WFlags f = 0 );
