@@ -22,7 +22,7 @@ namespace KMF {
 class IPAddress;
 
 class KMFIPv4AddressWidget : public KMyFirewallIPv4AdddressWidget {
-		Q_OBJECT
+		TQ_OBJECT
   
 
 	public:
