@@ -42,7 +42,7 @@ class KMFListViewItem;
 
 
 class KDE_EXPORT KMFListView : public TDEListView {
-	Q_OBJECT
+	TQ_OBJECT
   
 public:
 	KMFListView( TQWidget *parent = 0, const char *name = 0 );
