@@ -41,7 +41,7 @@ class NetfilterObject;
 
 class KMFMyNetworkWidget : public KMyFirewallMyNetworkWidget
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 
 public:
