@@ -33,7 +33,7 @@ class TQFocusEvent;
 
 namespace KMF {
 class KDE_EXPORT KMFNetworkWidget : public KMyFirewallNetworkWidget {
-	Q_OBJECT
+	TQ_OBJECT
   
 public:
 	KMFNetworkWidget(TQWidget *parent = 0, const char *name = 0);
