@@ -29,7 +29,7 @@ class KMFTransaction;
 
 class KMFTransactionLog : public KMyFirewallTransactionLog
 {
-		Q_OBJECT
+		TQ_OBJECT
   
 	
 	public: static KMFTransactionLog* instance();
