@@ -66,7 +66,7 @@ class KMFTarget;
 
 /** KMyFirewall is the base class of the project */
 class KMyFirewall : public KMFMainWindow {
-	Q_OBJECT
+	TQ_OBJECT
   
 
 public:
