@@ -45,7 +45,7 @@ class KMFRuleEditCustomOpt;
 @author Christian Hubinger
 */
 class KMFRuleOptionEditCustom : public KMFRuleOptionEditInterface {
-	Q_OBJECT
+	TQ_OBJECT
   
 public:
 	KMFRuleOptionEditCustom(TQObject *parent = 0, const char *name = 0, const TQStringList& = TQString());
@@ -68,7 +68,7 @@ private:
 
 
 class KMFRuleOptionEditCustomFactory : public KLibFactory {
-	Q_OBJECT
+	TQ_OBJECT
   
 public:
 	KMFRuleOptionEditCustomFactory( TQObject *parent = 0, const char *name = 0 );
@@ -76,7 +76,7 @@ public:
 /* 		delete s_instance; */
 	};
 	virtual TQObject* createObject( TQObject* parent = 0, const char* pname = 0,
-	                               const char* name = TQOBJECT_OBJECT_NAME_STRING,
+	                               const char* name = "TQObject",
 	                               const TQStringList &args = TQStringList() );
 	/*     static TDEInstance* instance(); */
 
